BEGIN;
\a


/**** Ex 1 **********************************************/
-- list of airports and their containing cities
select b.city_name, a.name, desig 
	from placenames a, citylimits2005 b 
	where a.desig = 'airport' 
		and within(a.the_geom, b.the_geom) 
	order by b.city_name;
select E'End\n\n';

/**** Ex 2 **********************************************/
-- county of airports > 2 with containing cities
select b.city_name, count(*) as ct, array_accum(substr(a.name,1,20)) as list 
	from placenames a, citylimits2005 b 
	where desig = 'airport' 
		and within(a.the_geom, b.the_geom) 
	group by b.city_name 
	having count(*) >= 2 
	order by count(*) desc;
select E'End\n\n';

/***** Ex 3 **********************************************/
-- list of airports within 10 miles of center of portland
drop table if exists airports_nearby;
CREATE TABLE airports_nearby (name text, desig text, elev text, distance float8) 
		with oids;
select addgeometrycolumn('airports_nearby', 'the_geom',  2992,  'POINT',      2);

insert into airports_nearby 
	select a.name, a.desig, a.elev, 
		distance(a.the_geom, b.centroid_geom)/(5280) as d, 
		a.the_geom
	from placenames a, citylimits2005 b 
	where b.city_name = 'Portland' 
		and a.desig = 'airport' 
		and distance(a.the_geom, b.centroid_geom) < (10 * 5280) 
	order by d;
select * from airports_nearby;

select E'End\n\n';

/**** Ex 4 **********************************************/
-- select some city limits based on their area
select city_name, area 
	from 
		(select city_name, 
				(area(the_geom)/(5280^2))::numeric(6,2) as area
		 from citylimits2005) b 
	where area > 1.0 
	order by area desc;
select E'End\n\n';

/**** Ex 5 **********************************************/
-- select all the counties touching the four Portland Area counties
select distinct b.county_nam 
	from counties a, counties b 
	where (a.county_nam ~ '^multnomah' 
				or a.county_nam ~ '^wash' 
				or a.county_nam ~ '^clack' 
				or a.county_nam ~ '^yamh') 
		and st_touches(a.the_geom, b.the_geom)
	order by b.county_nam;
select E'End\n\n';

/**** Ex 6 **********************************************/
-- collect all the touching counties 
drop table if exists collected_counties;
create table collected_counties (gid serial) with oids;
select addgeometrycolumn ('collected_counties', 'the_geom',2992,'POLYGON', 2);

insert INTO collected_counties (the_geom) 
	select  geomunion(the_Geom_simple) 
		from counties  
		where county_nam in ('yamhill', 'clackamas', 'multnomah', 'washington') ;

select E'End\n\n';

/****  Ex 7 ********************************************/
-- collect some points into a line order by st_y()
drop table if exists shiptracks;
create table shiptracks (gid serial) with oids;
select addgeometrycolumn ('shiptracks', 'the_geom',2992,'LINESTRING', 2);
insert into shiptracks (the_geom)
	select st_makeline_garray(array_accum(the_geom)) from (
		select the_geom from 
			(select the_geom, random() as r, 
					st_x(the_geom) as x, st_y(the_geom) as y 
				from placenames
    	    	where desig = 'airport'
				order by r
        		limit 10) a  
			order by y, x) b;
select E'End\n\n';

/***** Ex 7+1/2 *************************************************/
-- interpolate a point and fiddle with updating
select astext(st_line_interpolate_point(the_geom, .5)) from shiptracks;
select E'\n';
select astext(st_addpoint(the_geom, 
	st_geomfromtext('POINT(600000.0 1400000.0)', 2992), -1)) from shiptracks;
select E'\n';
select astext(st_addpoint(the_geom, 
	st_geomfromtext('POINT(600000.0 1400000.0)', 2992), 2)) from shiptracks;
select E'\n';
select st_y(st_endpoint(the_geom)) from shiptracks; 
update shiptracks set the_geom = st_addpoint(the_geom, 
	st_makepoint(st_x(st_endpoint(the_geom)) + 52800, 
	st_y(st_endpoint(the_geom)) + 52800));  -- add ten miles each time
select st_x(st_endpoint(the_geom)), st_y(st_endpoint(the_geom)) from shiptracks; 
select E'End\n\n';

/****  Ex 8 **********************************************/
-- Create polygon and convex hull from nearby airports
drop table if exists random_polys;
create table random_polys (id serial, description text) with oids;
select addgeometrycolumn('random_polys', 'the_geom',  2992,  'POLYGON',      2);

insert into random_polys (description, the_geom) select 
		'ch of pdx airps',
		(select st_convexhull(
			st_collect_garray(accum(the_geom))) from airports_nearby);

insert into random_polys (description, the_geom) 
	select 'multnomah less ch', geom 
		from (select * from st_dump(st_difference(  
			(select the_geom from counties where county_nam='multnomah'),
                    (select the_Geom from random_polys 
						where description = 'ch of pdx airps'))) as foo) a;

delete from random_polys  where description ~ '^ch';
select E'End\n\n';

-- Ex 9 do something with hwys
select hwyname, count(hwy_seg_id) as c 
		from hwys2006 group by hwyname order by c desc;
select hwyname, hwy_seg_id, 
		(length(the_geom)/5280)::numeric(5,3) as length, 
		astext(st_startpoint(the_geom)) as startp, 
		astext(st_endpoint(the_Geom)) as finishp,
		st_numpoints(the_geom) as nump
	from hwys2006 
	where hwyname = 'HATFIELD' 
	order by hwy_seg_id;
select E'End\n\n';

-- collect the hwys.  DOESN'T WORK because we get multi line strings, due, I think, to roads that
--   don't line up end to end...
/*
create table collected_hwys (gid serial, hwyname text) with oids; 
select addgeometrycolumn ('collected_hwys', 'the_geom',2992,'LINESTRINGM', 3);
insert into collected_hwys (hwyname, the_geom)
	select hwyname, geomunion(the_geom_simple)
	from (select hwyname, hwy_seg_id, the_geom_simple from hwys2006 order by hwyname, hwy_seg_id ) a
	group by hwyname;
*/


END;